pub struct GalaxyConfig {
pub system_count: usize,
pub size: GalaxySize,
pub systems: SystemConfig,
}Expand description
Configuration for the Galaxy
Fields
system_count: usizeStatic System Count
size: GalaxySizeGalaxy size
systems: SystemConfigSystem Config
Implementations
Sourceimpl GalaxyConfig
impl GalaxyConfig
Sourcepub fn get_structure_production(
&self,
structure: &str,
level: usize,
) -> ProductionConfig
pub fn get_structure_production( &self, structure: &str, level: usize, ) -> ProductionConfig
Get the production for a single structure at a given level.
Sourcepub fn get_structure_storage(
&self,
structure: &str,
level: usize,
) -> StorageConfig
pub fn get_structure_storage( &self, structure: &str, level: usize, ) -> StorageConfig
Get the storage for a single structure at a given level.