Galaxy

Struct Galaxy 

pub struct Galaxy { /* private fields */ }

Implementations

Source

impl Galaxy

pub fn new(config: GalaxyConfig, initial_tick: usize) -> Self

Create a new Galaxy

Uses a custom configuration struct to set up all the details

pub fn get_details( &mut self, tick: usize, coords: Coords, structure: Option<StructureType>, ) -> Result<Details, String>

Retrieve the details of a system, possibly scoped to a specific structure

pub fn get_config(&self) -> &GalaxyConfig

Get a pointer to the Config

pub fn stats(&mut self, tick: usize) -> Result<String, String>

Return basic stats about the Galaxy

pub fn systems(&self) -> &HashMap<Coords, System>

Retrieve the full list of systems

pub fn build( &mut self, tick: usize, coords: Coords, structure: StructureType, ) -> Result<Event, String>

Build a structure in a system