pub struct Galaxy { /* private fields */ }Implementations
Sourceimpl Galaxy
impl Galaxy
Sourcepub fn new(config: GalaxyConfig, initial_tick: usize) -> Self
pub fn new(config: GalaxyConfig, initial_tick: usize) -> Self
Create a new Galaxy
Uses a custom configuration struct to set up all the details
Sourcepub fn get_details(
&mut self,
tick: usize,
coords: Coords,
structure: Option<StructureType>,
) -> Result<Details, String>
pub fn get_details( &mut self, tick: usize, coords: Coords, structure: Option<StructureType>, ) -> Result<Details, String>
Retrieve the details of a system, possibly scoped to a specific structure
Sourcepub fn get_config(&self) -> &GalaxyConfig
pub fn get_config(&self) -> &GalaxyConfig
Get a pointer to the Config